@@ -3,14 +3,14 @@
  #  File        : gmic.h
  #                ( C++ header file )
  #
- #  Description : GREYC's Magic for Image Computing
- #                ( http://gmic.eu )
+ #  Description : GREYC's Magic for Image Computing - G'MIC API file
+ #                ( https://gmic.eu )
  #
  #  Note        : Include this file in your C++ source code, if you
  #                want to use the G'MIC interpreter in your own program.
  #
  #  Copyright   : David Tschumperle
- #                ( http://tschumperle.users.greyc.fr/ )
+ #                ( https://tschumperle.users.greyc.fr/ )
  #
  #  Licenses    : This file is 'dual-licensed', you have to choose one
  #                of the two licenses below to apply.
@@ -52,7 +52,7 @@
 */
 
 #ifndef gmic_version
-#define gmic_version 230
+#define gmic_version 261
 
 #ifndef gmic_pixel_type
 #define gmic_pixel_type float
@@ -74,12 +74,12 @@ namespace cimg_library {
 
   // Class 'gmic_image<T>'.
   template<typename T> struct gmic_image {
-    unsigned int _width;       // Number of image columns (dimension along the X-axis).
+    unsigned int _width;       // Number of image columns (dimension along the X-axis)
     unsigned int _height;      // Number of image lines (dimension along the Y-axis)
-    unsigned int _depth;       // Number of image slices (dimension along the Z-axis).
-    unsigned int _spectrum;    // Number of image channels (dimension along the C-axis).
-    bool _is_shared;           // Tells if the data buffer is shared by another structure.
-    T *_data;                  // Pointer to the first pixel value.
+    unsigned int _depth;       // Number of image slices (dimension along the Z-axis)
+    unsigned int _spectrum;    // Number of image channels (dimension along the C-axis)
+    bool _is_shared;           // Tells if the data buffer is shared by another structure
+    T *_data;                  // Pointer to the first pixel value
 
     // Destructor.
     ~gmic_image();
@@ -111,9 +111,9 @@ namespace cimg_library {
 
   // Class 'gmic_list<T>'.
   template<typename T> struct gmic_list {
-    unsigned int _width;           // Number of images in the list.
-    unsigned int _allocated_width; // Allocated items in the list (must be 2^N and >size).
-    gmic_image<T> *_data;          // Pointer to the first image of the list.
+    unsigned int _width;           // Number of images in the list
+    unsigned int _allocated_width; // Allocated items in the list (must be 2^N and >size)
+    gmic_image<T> *_data;          // Pointer to the first image of the list
 
     // Destructor.
     ~gmic_list();
@@ -167,14 +167,6 @@ namespace cimg_library {
 #endif
 #define cimg_plugin "gmic.cpp"
 
-// #ifdef cimg_use_abort
-// static struct cimg_is_abort {
-//   bool value, *ptr;
-//   cimg_is_abort():value(false),ptr(&value) {}
-// } _cimg_is_abort;
-// #define cimg_abort_test if (*_cimg_is_abort.ptr) throw CImgAbortException()
-// #endif // #ifdef cimg_use_abort
-
 #ifdef cimg_use_abort
 inline bool *gmic_abort_ptr(bool *const p_is_abort);
 #define cimg_abort_init bool *const gmic_is_abort = ::gmic_abort_ptr(0)
@@ -312,6 +304,10 @@ struct gmic {
 				   const unsigned int *const variables_sizes,
                                    const gmic_image<unsigned int> *const command_selection,
                                    const bool is_image_expr);
+
+  template<typename T>
+  void wait_threads(void *const p_gmic_threads, const bool try_abort, const T foo);
+
   template<typename T>
   gmic& print(const gmic_list<T>& list, const gmic_image<unsigned int> *const callstack_selection,
 	      const char *format, ...);
@@ -324,6 +320,9 @@ struct gmic {
   gmic& error(const gmic_list<T>& list, const gmic_image<unsigned int> *const callstack_selection,
 	      const char *const command, const char *format, ...);
 
+  template<typename T>
+  bool check_cond(const char *const expr, gmic_list<T>& images, const char *const command);
+
   template<typename T>
   gmic& debug(const gmic_list<T>& list, const char *format, ...);
 
@@ -394,7 +393,7 @@ struct gmic {
   unsigned long reference_time;
   unsigned int nb_dowhiles, nb_fordones, nb_repeatdones, nb_carriages, debug_filename, debug_line, cimg_exception_mode;
   int verbosity,render3d, renderd3d;
-  bool is_released, is_debug, is_running, is_start, is_return, is_quit, is_double3d, is_debug_info, check_elif,
+  bool is_released, is_debug, is_running, is_start, is_return, is_quit, is_double3d, is_debug_info,
     _is_abort, *is_abort, is_abort_thread;
   const char *starting_commands_line;
 };
